@@ -33,6 +33,9 @@ class Engine():
         system.create(self._entity_manager, self._component_manager,
                       self._system_manager, self._event_manager)
 
+    def destroy_system(self, system):
+        system.destroy()
+
     def generate_input(self, event_type='InputEvent', data=None):
         event = Event(event_type, data)
 
@@ -48,9 +51,9 @@ class Engine():
         systems = self.system_manager.system_types
 
         for system in systems.values():
-            system.update(time()-last_update)
+            system.update(time()-self.last_update)
 
-        last_update = time()
+        self.last_update = time()
 
         while not self.event_manager.empty:
             self.event_manager.update_events()
