@@ -54,6 +54,12 @@ class System():
 
         entity.create(self._entity_manager, self._component_manager)
 
+    def destroy_entity(self, entity):
+        if not self.initialized:
+            raise SystemNotCreated(self)
+
+        entity.destroy()
+
     def generate_event(self, event_type, data=None):
         if not self.initialized:
             raise SystemNotCreated(self)
@@ -64,9 +70,22 @@ class System():
     def send_event(self, event):
         if not self.initialized:
             raise SystemNotCreated(self)
-    
+
         self._event_manager.add_event(event)
 
+    def generate_engine_event(self, event_type, data=None):
+        if not self.initialized:
+            raise SystemNotCreated(self)
+
+        event = Event(event_type, data)
+        self._event_manager.add_engine_event(event)
+
+    def send_engine_event(self, event):
+        if not self.initialized:
+            raise SystemNotCreated(self)
+
+        self._event_manager.add_engine_event(event)
+
     def subscribe(self, fn, event_type):
         # TO DO: decorator
         if not self.initialized:
@@ -115,5 +134,8 @@ class System():
     def init(self):
         pass
 
+    def update(self, dt):
+        pass
+
     def final(self):
         pass
